==> ng-zorro-antd-0.5.0-rc.4.tgz: package/README.md <==
<p align="center">
  <a href="http://ng.ant.design">
    <img width="320" src="https://ng.ant.design/assets/img/zorro.svg">
  </a>
</p>

# NG-ZORRO
[![Build Status](https://travis-ci.org/NG-ZORRO/ng-zorro-antd.svg?branch=master)](https://travis-ci.org/NG-ZORRO/ng-zorro-antd)
[![npm package](https://img.shields.io/npm/v/ng-zorro-antd.svg)](https://www.npmjs.org/package/ng-zorro-antd)
[![Gitter](https://badges.gitter.im/ng-zorro/ng-zorro-antd.svg)](https://gitter.im/ng-zorro/ng-zorro-antd?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)

An enterprise-class UI components based on Ant Design and Angular.

[中文 README](README-zh_CN.md)


## Features

- An enterprise-class UI design language for web applications.
- A set of high-quality Angular components out of the box.
- Written in TypeScript with complete define types.

## Environment Support

* Modern browsers and Internet Explorer 9+（with [polyfills](https://angular.cn/guide/browser-support)）。

## Angular Version Support

* Angular`^4.0.0`


## Install

```bash
$ npm install ng-zorro-antd --save
```

## Development

```bash
$ git clone git@github.com:NG-ZORRO/ng-zorro-antd.git
$ npm install
$ npm start
```


## Links

- [Home page](http://ng.ant.design)
- [Angular](https://angular.io/)
- [Angular CLI](https://cli.angular.io/)
- [TypeScript](https://www.typescriptlang.org/)
- [RxJS 5](https://github.com/ReactiveX/rxjs)


## Contributing

We welcome all contributions. Please read our [CONTRIBUTING.md](https://github.com/NG-ZORRO/ng-zorro-antd/blob/master/CONTRIBUTING.md) first.
You can submit any ideas as [pull request](https://github.com/NG-ZORRO/ng-zorro-antd/pulls)，or as [GitHub issues](https://github.com/NG-ZORRO/ng-zorro-antd/issues)。

==> ng-zorro-antd-0.6.0-rc.1.tgz: package/README.md <==
<p align="center">
  <a href="http://ng.ant.design">
    <img width="320" src="https://ng.ant.design/assets/img/zorro.svg">
  </a>
</p>

# NG-ZORRO
[![Build Status](https://travis-ci.org/NG-ZORRO/ng-zorro-antd.svg?branch=master)](https://travis-ci.org/NG-ZORRO/ng-zorro-antd)
[![npm package](https://img.shields.io/npm/v/ng-zorro-antd.svg)](https://www.npmjs.org/package/ng-zorro-antd)
[![Gitter](https://badges.gitter.im/ng-zorro/ng-zorro-antd.svg)](https://gitter.im/ng-zorro/ng-zorro-antd?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)

An enterprise-class UI components based on Ant Design and Angular.

[中文 README](README-zh_CN.md)


## Features

- An enterprise-class UI design language for web applications.
- A set of high-quality Angular components out of the box.
- Written in TypeScript with complete define types.

## Environment Support

* Modern browsers and Internet Explorer 9+（with [polyfills](https://v2.angular.io/docs/ts/latest/guide/browser-support.html)）。

## Angular Version Support

* Angular`^4.4.4`


## Install

```bash
$ npm install ng-zorro-antd --save
```

## Development

```bash
$ git clone git@github.com:NG-ZORRO/ng-zorro-antd.git
$ npm install
$ npm start
```


## Links

- [Home page](http://ng.ant.design)
- [Angular](https://angular.io/)
- [Angular CLI](https://cli.angular.io/)
- [TypeScript](https://www.typescriptlang.org/)
- [RxJS 5](https://github.com/ReactiveX/rxjs)


## Contributing

We welcome all contributions. Please read our [CONTRIBUTING.md](https://github.com/NG-ZORRO/ng-zorro-antd/blob/master/CONTRIBUTING.md) first.
You can submit any ideas as [pull request](https://github.com/NG-ZORRO/ng-zorro-antd/pulls)，or as [GitHub issues](https://github.com/NG-ZORRO/ng-zorro-antd/issues)。
